==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm2015/lib/igc-tool-action-icon-menu-component.js <==
import { IgcToolActionIconButtonComponent } from "./igc-tool-action-icon-button-component";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconMenuComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconMenuComponent extends IgcToolActionIconButtonComponent {
        createImplementation() {
            return new ToolActionIconMenu();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconMenuComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = names;
            }
            return IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent;
        }
        static register() {
            if (!IgcToolActionIconMenuComponent._isElementRegistered) {
                IgcToolActionIconMenuComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconMenuComponent.htmlTagName, IgcToolActionIconMenuComponent);
            }
        }
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get arrowStroke() {
            return brushToString(this.i.ju);
        }
        set arrowStroke(v) {
            this.i.ju = stringToBrush(v);
            this._a("arrowStroke", brushToString(this.i.ju));
        }
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get actualArrowStroke() {
            return brushToString(this.i.jt);
        }
        set actualArrowStroke(v) {
            this.i.jt = stringToBrush(v);
            this._a("actualArrowStroke", brushToString(this.i.jt));
        }
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get showArrowIcon() {
            return this.i.jg;
        }
        set showArrowIcon(v) {
            this.i.jg = ensureBool(v);
            this._a("showArrowIcon", this.i.jg);
        }
        exportVisualData() {
            let iv = this.i.cn();
            return (iv);
        }
    }
    IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = null;
    IgcToolActionIconMenuComponent.htmlTagName = "igc-tool-action-icon-menu";
    IgcToolActionIconMenuComponent._isElementRegistered = false;
    return IgcToolActionIconMenuComponent;
})();

==> igniteui-webcomponents-layouts-5.1.0.tgz: package/esm2015/lib/igc-tool-action-icon-menu-component.js <==
import { IgcToolActionIconButtonComponent } from "./igc-tool-action-icon-button-component";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
export let IgcToolActionIconMenuComponent = /*@__PURE__*/ (() => {
    class IgcToolActionIconMenuComponent extends IgcToolActionIconButtonComponent {
        createImplementation() {
            return new ToolActionIconMenu();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent == null) {
                let names = getAllPropertyNames(IgcToolActionIconMenuComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = names;
            }
            return IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent;
        }
        static register() {
            if (!IgcToolActionIconMenuComponent._isElementRegistered) {
                IgcToolActionIconMenuComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcToolActionIconMenuComponent.htmlTagName, IgcToolActionIconMenuComponent);
            }
        }
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get arrowStroke() {
            return brushToString(this.i.jv);
        }
        set arrowStroke(v) {
            this.i.jv = stringToBrush(v);
            this._a("arrowStroke", brushToString(this.i.jv));
        }
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get actualArrowStroke() {
            return brushToString(this.i.ju);
        }
        set actualArrowStroke(v) {
            this.i.ju = stringToBrush(v);
            this._a("actualArrowStroke", brushToString(this.i.ju));
        }
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get showArrowIcon() {
            return this.i.jh;
        }
        set showArrowIcon(v) {
            this.i.jh = ensureBool(v);
            this._a("showArrowIcon", this.i.jh);
        }
        exportVisualData() {
            let iv = this.i.cn();
            return (iv);
        }
    }
    IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = null;
    IgcToolActionIconMenuComponent.htmlTagName = "igc-tool-action-icon-menu";
    IgcToolActionIconMenuComponent._isElementRegistered = false;
    return IgcToolActionIconMenuComponent;
})();
